@@ -101,7 +101,7 @@ class NotebookProcessor():
         return python_file_path
 
     def write_requirements_file(self, requirements):
-        python_file_path = os.path.dirname(self.nb_path) + '/requirements.txt'
+        python_file_path = os.path.dirname(self.nb_path) + '/proxy_requirements.txt'
         python_file = open(python_file_path, "w+")
         python_file.write(requirements)
         return python_file_path
